@@ -6,6 +6,7 @@ from mkdocs import utils
 def create_info_box(soup,config):
 
     always_hint = config.get("always_show_hint",False)
+    key = config.get("key")
 
     if always_hint:
         info_box = soup.new_tag("div",**{
@@ -16,21 +17,18 @@ def create_info_box(soup,config):
             "class": "panzoom-info-box panzoom-hidden"
         })
 
-    info_box.string = 'Press "Alt" / "Option" to enable Pan & Zoom'
+    if key == "alt":
+        info_box.string = 'Press "Alt" / "Option" to enable Pan & Zoom'
+    elif key == "ctrl":
+        info_box.string = 'Press "Ctrl" to enable Pan & Zoom'
+    elif key == "shift":
+        info_box.string = 'Press "Shift" to enable Pan & Zoom'
+
+    # info_box.string = 'Press "Alt" / "Option" to enable Pan & Zoom'
 
     return info_box
 
-def create_panzoom_box(soup,config):
-
-    always_hint = config.get("always_show_hint",False)
-
-    panzoom_box = soup.new_tag("div",**{"class": "panzoom-box"})
-    nav = soup.new_tag("nav", **{
-        "class": "panzoom-top-nav",
-        #"title": "material-fullscreen"
-    })
-
-
+def create_button_info(soup):
     info = soup.new_tag("button", **{
         "class": "panzoom-info panzoom-button"
     })
@@ -49,6 +47,9 @@ def create_panzoom_box(soup,config):
 
     info.append(info_svg)
 
+    return info
+
+def create_button_reset(soup):
     reset = soup.new_tag("button", **{
         "class": "panzoom-reset panzoom-button"
     })
@@ -67,8 +68,9 @@ def create_panzoom_box(soup,config):
 
     reset.append(reset_svg)
 
+    return reset
 
-
+def create_button_max(soup):
     max = soup.new_tag("button", **{
         "class": "panzoom-max panzoom-button"
     })
@@ -87,9 +89,18 @@ def create_panzoom_box(soup,config):
 
     max.append(max_svg)
 
-    min = soup.new_tag("button", **{
-        "class": "panzoom-min panzoom-button panzoom-hidden"
-    })
+    return max
+
+def create_button_min(soup,hidden=True):
+
+    if hidden:
+        min = soup.new_tag("button", **{
+            "class": "panzoom-min panzoom-button panzoom-hidden"
+        })
+    else:
+        min = soup.new_tag("button", **{
+            "class": "panzoom-min panzoom-button"
+        })
 
     min_svg = soup.new_tag("svg", **{
         "class": "panzoom-icon",
@@ -104,6 +115,26 @@ def create_panzoom_box(soup,config):
     min_svg.append(min_path)
     min.append(min_svg)
 
+    return min
+
+def create_panzoom_box(soup,config, id):
+
+    always_hint = config.get("always_show_hint",False)
+
+    panzoom_box = soup.new_tag("div",**{"class": "panzoom-box", "id": "panzoom"+str(id)})
+
+    panzoom_box.attrs["data-key"] = config.get('key',"none")
+
+    nav = soup.new_tag("nav", **{
+        "class": "panzoom-top-nav",
+        #"title": "material-fullscreen"
+    })
+
+    info = create_button_info(soup)
+    reset = create_button_reset(soup)
+    max = create_button_max(soup)
+    min = create_button_min(soup)
+
     # remove info button on permanent info banner
     if not always_hint:
         nav.append(info)
@@ -128,3 +159,26 @@ def create_js_script(soup,page):
 def create_js_script_plugin(soup,page):
     src= utils.get_relative_url(utils.normalize_url("assets/javascripts/zoompan.js"),page.url)
     return soup.new_tag("script", src=src)
+
+def create_fullscreen_modal(soup,config):
+    modal = soup.new_tag("div",**{"class": "panzoom-fullscreen-modal", "id": "panzoom-fullscreen-modal"})
+
+    nav = soup.new_tag("nav", **{
+        "class": "panzoom-top-nav",
+        #"title": "material-fullscreen"
+    })
+
+    info = create_button_info(soup)
+    reset = create_button_reset(soup)
+    min = create_button_min(soup,False)
+
+    # remove info button on permanent info banner
+    if not config.get("always_show_hint",False):
+        nav.append(info)
+
+    nav.append(reset)
+    nav.append(min)
+
+    modal.append(nav)
+
+    return modal
